@@ -1,4 +1,5 @@
 import logging
+import os
 import pathlib
 
 import attr
@@ -18,8 +19,9 @@ logging.getLogger("gensim").setLevel(logging.ERROR)
 logging.getLogger("filelock").setLevel(logging.ERROR)
 logging.basicConfig(level=logging.INFO)
 
-temp = pathlib.PosixPath
-pathlib.PosixPath = pathlib.WindowsPath
+if os.name == "nt":
+    temp = pathlib.PosixPath
+    pathlib.PosixPath = pathlib.WindowsPath
 
 
 @attr.s
